ChangeOwnerFrom

Type Alias ChangeOwnerFrom 

pub type ChangeOwnerFrom<AccountId> = CheckState<Owner<AccountId>, Owner<AccountId>>;
The operation implementation must check if the given account owns the asset and only then perform the owner update to the one supplied to the Update::update function.

Aliased Type

pub struct ChangeOwnerFrom<AccountId>(pub AccountId, pub Owner<AccountId>);

Tuple Fields

0: AccountId1: Owner<AccountId>