IfOwnedBy

Type Alias IfOwnedBy 

pub type IfOwnedBy<AccountId, Inner = NoParams> = CheckState<Owner<AccountId>, Inner>;
The operation implementation must check if the given account owns the asset and act according to the inner strategy.

Aliased Type

pub struct IfOwnedBy<AccountId, Inner = NoParams>(pub AccountId, pub Inner);

Tuple Fields

0: AccountId1: Inner