WithWitness

Type Alias WithWitness 

pub type WithWitness<WitnessData, Inner = NoParams> = CheckState<Witness<WitnessData>, Inner>;
The operation implementation must check if the given witness represents the correct state of the asset. If so, the operation must act according to the inner strategy.

Aliased Type

pub struct WithWitness<WitnessData, Inner = NoParams>(pub WitnessData, pub Inner);

Tuple Fields

0: WitnessData1: Inner